@@ -8,11 +8,7 @@
 #endif
 
 #define STRIFNULL(f,cs) if (f == NULL) f = g_strdup(cs);
-#ifdef ARCH_arm
-#define UNKIFNULL(f) STRIFNULL(f, _("Kunpeng 920") )
-#else
-#define UNKIFNULL(f) STRIFNULL(f, _("(Unknow)") )
-#endif
+#define UNKIFNULL(f) STRIFNULL(f, _("(Unknown)") )
 #define EMPIFNULL(f) STRIFNULL(f, "")
 
 const gchar *byte_order_str(void);
@@ -51,4 +47,6 @@ void cputopo_free(cpu_topology_data *cputd);
 
 gchar *cputopo_section_str(cpu_topology_data *cputd);
 
+int cpu_procs_cores_threads_nodes(int *p, int *c, int *t, int *n);
+
 #endif
