@@ -1,10 +1,10 @@
 /*
  *    HardInfo - Displays System Information
- *    Copyright (C) 2003-2007 Leandro A. F. Pereira <leandro@hardinfo.org>
+ *    Copyright (C) 2003-2007 L. A. F. Pereira <l@tia.mat.br>
  *
  *    This program is free software; you can redistribute it and/or modify
  *    it under the terms of the GNU General Public License as published by
- *    the Free Software Foundation, version 2.
+ *    the Free Software Foundation, version 2 or later.
  *
  *    This program is distributed in the hope that it will be useful,
  *    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -19,16 +19,12 @@
 #ifndef __STOCK_H__
 #define __STOCK_H__
 
-#define HI_STOCK_REPORT		"hi-stock-report"
-#define HI_STOCK_INTERNET	"hi-stock-internet"
-#define HI_STOCK_MODULE		"hi-stock-module"
-#define HI_STOCK_ABOUT_MODULES	"hi-stock-about-modules"
-#define HI_STOCK_SYNC_MENU	"hi-stock-sync-menu"
-#define HI_STOCK_DONATE		"hi-stock-donate"
-#define HI_STOCK_SERVER		"hi-stock-server"
+#define HI_STOCK_REFRESH "hi-stock-refresh"
+#define HI_STOCK_REPORT "hi-stock-report"
+#define HI_STOCK_SYNC "hi-stock-sync"
+#define HI_STOCK_UPDATES "hi-stock-updates"
 
 void stock_icons_init(void);
 void stock_icon_register(gchar *filename, gchar *stock_id);
-void stock_icon_register_pixbuf(GdkPixbuf *pixbuf, gchar *stock_id);
 
 #endif	/* __STOCK_H__ */
